Rclique(X, path=NULL, ...)"phylip.data" with a set of binary characters; or a matrix.path = NULL, the R will search several commonly used directories for the correct executable file."phylo" that is the optimized tree.
quiet suppress some output to R console (defaults to quiet = FALSE); ancestral vector of ancestral states; weights vector of weights of length equal to the number of columns in X (defaults to unweighted); minimum.clique, if specified, will cause Rclique to print out all cliques (and corresponding trees) greater than minimum.clique; outgroup outgroup if outgroup rooting of the estimated tree is desired; and cleanup remove PHYLIP input & output files after the analysis is completed (defaults to cleanup = TRUE).More information about the clique program in PHYLIP can be found here http://evolution.genetics.washington.edu/phylip/doc/clique.html.
Obviously, use of any of the functions of this package requires that PHYLIP (Felsenstein 1989, 2013) should first be installed. Instructions for installing PHYLIP can be found on the PHYLIP webpage: http://evolution.genetics.washington.edu/phylip.html.
Felsenstein, J. (1989) PHYLIP--Phylogeny Inference Package (Version 3.2). Cladistics, 5, 164-166.
Felsenstein, J. (2013) PHYLIP (Phylogeny Inference Package) version 3.695. Distributed by the author. Department of Genome Sciences, University of Washington, Seattle.
Le Quesne, W.J. (1969) A method of selection of characters in numerical taxonomy. Systematic Zoology, 18, 201-205.
Rdnacomp, Rmix
## Not run:
# data(primates.bin)
# tree<-Rclique(primates.bin)
# ## End(Not run)
Run the code above in your browser using DataLab