Rdolpenny(X, path=NULL, ...)"phylo" or "multiPhylo" that is the tree or trees with the best parsimony score. tree$score gives the parsimony score, for "phylo" object tree.quiet suppress some output to R console (defaults to quiet = FALSE); method indicating whether Dollo (method="dollo", the default) or polymorphism (method="polymorphism") should be used; groups number of groups of 1,000 trees (defaults to groups = 100); report reporting frequency, in numbers of trees (defaults to report = 1000); simple simple branch & bound (defaults to simple = TRUE); threshold threshold value for threshold parsimony (defaults to ordinary parsimony); ancestors vector of ancestral states, which allows for the unordered Dollo parsimony method of Felsenstein (1984); weights vector of weights of length equal to the number of columns in X (defaults to unweighted); outgroup outgroup if outgroup rooting of the estimated tree is desired; and cleanup remove PHYLIP input & output files after the analysis is completed (defaults to cleanup = TRUE).
More information about the dolpenny program in PHYLIP can be found here Rdnaparsdata(primates.bin)
tree<-Rdolpenny(primates.bin)Run the code above in your browser using DataLab