Rprotdist(X, path=NULL, ...)"dist".quiet suppress some output to R console (defaults to quiet = FALSE); model can be "JTT" (Jones et al. 1992), "PMB" (Veerassamy et al. 2003), "PAM" (Dayhoff & Eck 1968; Dayhoff et al. 1979; Koisol & Goldman 2005), "Kimura" (a simple model based on Kimura 1980), "similarity" which gives the similarity between sequences, and "categories" which is due to Felsenstein; gamma alpha shape parameter of a gamma model of rate heterogeneity among sites (defaults to no gamma rate heterogeneity) - note that gamma rate heterogeneity does not apply to model = "Kimura" or model = "similarity"; kappa transition:transversion ratio (defaults to kappa = 2.0), genetic.code, type of genetic code to assume (options are "universal", the default, "mitochondrial", "vertebrate.mitochondrial", "fly.mitochondrial", and "yeast.mitochondrial"), categorization, categorization scheme for amino acids (options are "GHB", the George et al. 1988 classification, "Hall", a classification scheme provided by Ben Hall, and "chemical", a scheme based on Conn & Stumpf 1963); and, finally, ease, a numerical parameter that indicates the facility of getting between amino acids of different categories in which 0 is nearly impossible, and 1 is no difficulty (defaults to ease = 0.457) - note that kappa, bf, genetic.code, categorization, and ease apply only to model = "categories"; rates vector of rates (defaults to single rate); rate.categories vector of rate categories corresponding to the order of rates; weights vector of weights of length equal to the number of columns in X (defaults to unweighted); and cleanup remove PHYLIP input & output files after the analysis is completed (defaults to cleanup = TRUE).
More information about the protdist program in PHYLIP can be found here Rneighbordata(chloroplast)
D<-Rprotdist(chloroplast,model="PAM")
tree<-Rneighbor(D)Run the code above in your browser using DataLab