Rrestml(X, path=NULL, ...)"rest.data" containing data for restriction sites.path = NULL, the R will search several paths for restml. See details for more information."dist".
quiet suppress some output to R console (defaults to quiet = FALSE); tree object of class "phylo" - if supplied, then the model will be optimized on a fixed input topology; speedier speedier but rougher analysis (defaults to speedier = FALSE); global perform global search (defaults to global = TRUE); random.order add taxa to tree in random order (defaults to random.order = TRUE); random.addition number of random addition replicates for random.order = TRUE (defaults to random.addition = 10); site.length the restriction site length (defaults to site.length=6); outgroup outgroup if outgroup rooting of the estimated tree is desired; and cleanup remove PHYLIP input & output files after the analysis is completed (defaults to cleanup = TRUE).More information about the restml program in PHYLIP can be found here http://evolution.genetics.washington.edu/phylip/doc/restml.html.
Obviously, use of any of the functions of this package requires that PHYLIP (Felsenstein 1989, 2013) should first be installed. Instructions for installing PHYLIP can be found on the PHYLIP webpage: http://evolution.genetics.washington.edu/phylip.html.
Felsenstein, J. (1992) Phylogenies from restriction sites, a maximum likelihood approach. Evolution, 46, 159-173.
Felsenstein, J. (2013) PHYLIP (Phylogeny Inference Package) version 3.695. Distributed by the author. Department of Genome Sciences, University of Washington, Seattle.
Nei, M., Li, W.-H. (1979) Mathematical model for studying genetic variation in terms of restriction endonucleases. Proceedings of the National Academy of Sciences, 76, 5269-5273.
Smouse, P. E., Li, W.-H. (1987) Likelihood analysis of mitochondrial restriction-cleavage patterns for the human-chimpanzee-gorilla trichotomy. Evolution, 41, 1162-1176.
Rrestdist
## Not run:
# data(restriction.data)
# tree<-Rrestml(restriction.data)
# ## End(Not run)
Run the code above in your browser using DataLab